@@ -3,6 +3,8 @@
 It also contains score collections such as arrays and matrices.
 """
 
-from .base import ErrorScore, Score
+from .base import ErrorScore, Score, score_logger
 from .complete import *
 from .incomplete import *
+
+
