@@ -8,12 +8,11 @@ from typing import List, Optional, Tuple, Union
 
 from sciunit.scores.collections import ScoreMatrix
 
-from .base import SciUnit, TestWeighted
+from .base import SciUnit, TestWeighted, log
 from .models import Model
 from .scores import NoneScore
 from .scores.collections import ScoreMatrix
 from .tests import Test
-from .utils import log
 
 
 class TestSuite(SciUnit, TestWeighted):
@@ -268,20 +267,21 @@ class TestSuite(SciUnit, TestWeighted):
         if self.is_skipped(model):
             score = NoneScore(None)
         else:
-            log(
-                "Executing test <i>%s</i> on model <i>%s</i>" % (test, model),
-                end=u"... ",
-            )
+            #log(
+            #    "Executing test <i>%s</i> on model <i>%s</i>" % (test, model),
+            #    end=u"... ",
+            #)
             score = test.judge(
                 model,
                 skip_incapable=skip_incapable,
                 stop_on_error=stop_on_error,
                 deep_error=deep_error,
             )
-            log(
-                'Score is <a style="color: rgb(%d,%d,%d)">' % score.color()
-                + "%s</a>" % score
-            )
+            score.log()
+            #log(
+            #    'Score is <a style="color: rgb(%d,%d,%d)">' % score.color()
+            #    + "%s</a>" % score
+            #)
         sm.loc[model, test] = score
         return score
 
