@@ -1,13 +1,11 @@
 """SciUnit tests live in this module."""
 
+from copy import deepcopy
 import inspect
 import traceback
-
-# from sciunit.models.examples import ConstModel, UniformModel
 from typing import Any, List, Optional, Tuple, Union
 
-from sciunit.base import SciUnit
-
+from .base import SciUnit, config
 from .capabilities import ProducesNumber
 from .errors import (
     CapabilityError,
@@ -18,7 +16,7 @@ from .errors import (
 )
 from .models import Model
 from .scores import BooleanScore, ErrorScore, NAScore, NoneScore, Score, TBDScore
-from .utils import config_get, dict_combine
+from .utils import dict_combine
 from .validators import ObservationValidator, ParametersValidator
 
 
@@ -52,7 +50,11 @@ class Test(SciUnit):
         self.compute_params()
 
         self.observation = observation
-        if config_get("PREVALIDATE", False):
+        
+        # Fall back to the score class's observation_schema if the test class doesn't have one
+        if self.observation_schema is None:
+            self.observation_schema = deepcopy(self.score_type.observation_schema)
+        if config.get("PREVALIDATE", False):
             self.validate_observation(self.observation)
 
         if self.score_type is None or not issubclass(self.score_type, Score):
@@ -86,10 +88,16 @@ class Test(SciUnit):
     Can also be a list of schemas, one of which the observation must match.
     If it is a list, each schema in the list can optionally be named by putting
     (name, schema) tuples in that list."""
+    
+    observation_validator = ObservationValidator
 
     params_schema = None
     """A schema that the params must adhere to (validated by cerberus).
     Can also be a list of schemas, one of which the params must match."""
+    
+    params_validator = ParametersValidator
+    
+    state_hide = ['last_model']
 
     def compute_params(self) -> None:
         """Compute new params from existing `self.params`.
@@ -112,12 +120,9 @@ class Test(SciUnit):
         Returns:
             dict: The observation that was validated.
         """
-        if not observation:
-            raise ObservationError("Observation is missing.")
+        observation = self.score_type.observation_preprocess(observation)
         if not isinstance(observation, dict):
             raise ObservationError("Observation is not a dictionary.")
-        if "mean" in observation and observation["mean"] is None:
-            raise ObservationError("Observation mean cannot be 'None'.")
         if self.observation_schema:
             if isinstance(self.observation_schema, list):
                 schemas = [
@@ -127,9 +132,10 @@ class Test(SciUnit):
             else:
                 schema = {"schema": self.observation_schema, "type": "dict"}
             schema = {"observation": schema}
-            v = ObservationValidator(schema, test=self)
+            v = self.observation_validator(schema, test=self)
             if not v.validate({"observation": observation}):
                 raise ObservationError(v.errors)
+        observation = self.score_type.observation_postprocess(observation)
         return observation
 
     @classmethod
@@ -170,7 +176,7 @@ class Test(SciUnit):
             else:
                 schema = {"schema": self.params_schema, "type": "dict"}
             schema = {"params": schema}
-            v = ParametersValidator(schema, test=self)
+            v = self.params_validator(schema, test=self)
             if not v.validate({"params": params}):
                 raise ParametersError(v.errors)
         return params
@@ -369,28 +375,33 @@ class Test(SciUnit):
             ) % (self.name, self.score_type.__name__, score.__class__.__name__)
             raise InvalidScoreError(msg)
 
-    def _judge(self, model: Model, skip_incapable: bool = True) -> Score:
+    def _judge(self, model: Model, skip_incapable: bool = True, cached_prediction=False) -> Score:
         """Generate a score for the model (internal API use only).
 
         Args:
             model (Model): A sciunit model instance.
             skip_incapable (bool, optional): Skip the incapable tests. Defaults to True.
+            predict: Whether to make a prediction or use a pre-computed one
 
         Returns:
             Score: The generated score.
         """
-        # 1.
-        self.check_capabilities(model, skip_incapable=skip_incapable)
+        if not cached_prediction:
+            # 1.
+            self.check_capabilities(model, skip_incapable=skip_incapable)
 
         # 2.
         validated = self.validate_observation(self.observation)
         if validated is not None:
             self.observation = validated
 
-        # 3.
-        prediction = self.generate_prediction(model)
-        self.check_prediction(prediction)
-        self.last_model = model
+        if not cached_prediction:
+            # 3.
+            prediction = self.generate_prediction(model)
+            self.check_prediction(prediction)
+            self.last_model = model
+        else:
+            prediction = self.prediction
 
         # 4.
         score = self.compute_score(self.observation, prediction)
@@ -403,8 +414,21 @@ class Test(SciUnit):
 
         # 6.
         self._bind_score(score, model, self.observation, prediction)
-
+        
         return score
+    
+    
+    def feature_judge(
+        self,
+        model: Model,
+        skip_incapable: bool = False,
+        stop_on_error: bool = True,
+        deep_error: bool = False,
+    ) -> Score:
+        """For backwards compatibility"""
+        return self.judge(model, skip_incapable=skip_incapable, stop_on_error=stop_on_error,
+                          deep_error=deep_error, cached_prediction=True)
+
 
     def judge(
         self,
@@ -412,6 +436,7 @@ class Test(SciUnit):
         skip_incapable: bool = False,
         stop_on_error: bool = True,
         deep_error: bool = False,
+        cached_prediction: bool = False
     ) -> Score:
         """Generate a score for the provided model (public method).
 
@@ -463,10 +488,12 @@ class Test(SciUnit):
             )
 
         if deep_error:
-            score = self._judge(model, skip_incapable=skip_incapable)
+            score = self._judge(model, skip_incapable=skip_incapable,
+                                cached_prediction=cached_prediction)
         else:
             try:
-                score = self._judge(model, skip_incapable=skip_incapable)
+                score = self._judge(model, skip_incapable=skip_incapable,
+                                    cached_prediction=cached_prediction)
             except CapabilityError as e:
                 score = NAScore(str(e))
                 score.model = model
